@@ -1,7 +1,5 @@
 context("test get_empty_geometry_instances")
 
-library(sf) # It has to be included even if it is not used directly.
-
 test_that("get_empty_geometry_instances works", {
   us_state_point <-
     coordinates_to_geometry(layer_us_state,
@@ -10,10 +8,10 @@ test_that("get_empty_geometry_instances works", {
   state <-
     geolevel(name = "state",
              layer = layer_us_state,
-             key = c("geoid")) %>%
+             key = c("geoid")) |>
     add_geometry(layer = us_state_point)
 
-  res <- state %>% get_empty_geometry_instances(geometry = "point")
+  res <- state |> get_empty_geometry_instances(geometry = "point")
 
   expect_equal(res,
                structure(
