@@ -1,7 +1,5 @@
 context("test relate_levels")
 
-library(sf) # It has to be included even if it is not used directly.
-
 test_that("relate_levels works", {
   region <-
     geolevel(name = "region",
@@ -13,10 +11,10 @@ test_that("relate_levels works", {
              key = c("geoid"))
   gd <-
     geodimension(name = "gd_us",
-                 level = region) %>%
+                 level = region) |>
     add_level(division)
 
-  gd <- gd %>%
+  gd <- gd |>
     relate_levels(lower_level_name = "division",
                   upper_level_name = "region",
                   by_geography = TRUE)
